@@ -12,7 +12,7 @@ use base qw(Net::DNS::Resolver::Base DynaLoader), OS_CONF;
 our $VERSION;
 
 BEGIN {
-	$VERSION = '1.27_03';
+	$VERSION = '1.27_04';
 	eval { __PACKAGE__->bootstrap($VERSION) };
 }
 
@@ -23,6 +23,9 @@ use constant UB_VERSION => scalar eval {
 };
 
 use constant UB_CONTEXT => 'Net::DNS::Resolver::Unbound::Context';
+use constant IRRELEVENT => qw(igntc nameserver4 nameserver6 nameservers
+		persistent_tcp persistent_udp port retrans retry
+		srcaddr4 srcaddr6 srcport tcp_timeout udp_timeout usevc);
 
 use constant IP_PREF	 => UB_VERSION > 11100;
 use constant ADD_TA_AUTR => UB_CONTEXT->can('add_ta_autr');
@@ -101,6 +104,7 @@ sub new {
 	my ( $class, @args ) = @_;
 	my $self = $class->SUPER::new();
 	$self->nameservers( $self->SUPER::nameservers );
+	delete $self->{$_} for IRRELEVENT;
 	$self->_finalise_config;				# default configuration
 	$self->{update} = {} if @args;				# force context rebuild
 	while ( my $attr = shift @args ) {
@@ -208,7 +212,7 @@ sub bgread {
 	my ( $self, $handle ) = @_;
 	return unless $handle;
 
-	$self->{ub_ctx}->ub_wait if &bgbusy;
+	$self->{ub_ctx}->ub_wait;
 	$self->errorstring( $handle->err );
 
 	my $reply = $self->_decode_result( $handle->result ) || return;
